stm32-metapac

Crates

git

Versions

stm32u5f9zi

Flavors

Mdf

Struct Mdf 

pub struct Mdf { /* private fields */ }
Multi-function digital filter.

Implementations



impl Mdf

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn gcr(self) -> Reg<Gcr, RW>

MDF global control register.

pub const fn ckgcr(self) -> Reg<Ckgcr, RW>

MDF clock generator control register.

pub const fn sitfcr(self, n: usize) -> Reg<Sitfcr, RW>

This register is used to control the serial interfaces (SITFx).

pub const fn bsmxcr(self, n: usize) -> Reg<Bsmxcr, RW>

This register is used to select the bitstream to be provided to the corresponding digital filter and to the SCD.

pub const fn dfltcr(self, n: usize) -> Reg<Dfltcr, RW>

This register is used to control the digital filter x.

pub const fn dfltcicr(self, n: usize) -> Reg<Dfltcicr, RW>

This register is used to control the main CIC filter.

pub const fn dfltrsfr(self, n: usize) -> Reg<Dfltrsfr, RW>

This register is used to control the reshape and HPF filters.

pub const fn dfltintr(self, n: usize) -> Reg<Dfltintr, RW>

This register is used to the integrator (INT) settings.

pub const fn oldcr(self, n: usize) -> Reg<Oldcr, RW>

This register is used to configure the Out-of Limit Detector function.

pub const fn oldthlr(self, n: usize) -> Reg<Oldthlr, RW>

This register is used for the adjustment of the Out-off Limit low threshold.

pub const fn oldthhr(self, n: usize) -> Reg<Oldthhr, RW>

This register is used for the adjustment of the Out-off Limit high threshold.

pub const fn dlycr(self, n: usize) -> Reg<Dlycr, RW>

This register is used for the adjustment stream delays.

pub const fn scdcr(self, n: usize) -> Reg<Scdcr, RW>

This register is used for the adjustment stream delays.

pub const fn dfltier(self, n: usize) -> Reg<Dfltier, RW>

This register is used for allowing or not the events to generate an interrupt.

pub const fn dfltisr(self, n: usize) -> Reg<Dfltisr, RW>

MDF DFLT0 interrupt status register 0.

pub const fn oeccr(self, n: usize) -> Reg<Oeccr, RW>

This register contains the offset compensation value.

pub const fn snpsdr(self, n: usize) -> Reg<Snpsdr, R>

This register is used to read the data processed by each digital filter in snapshot mode.

pub const fn dfltdr(self, n: usize) -> Reg<Dfltdr, R>

This register is used to read the data processed by each digital filter.